<?php
/**
 * Active plugins
 */
if ( ! function_exists( 'get_active_plugins' ) ) {
	function get_active_plugins() {
		$active_plugins = (array) get_option( 'active_plugins', array() );
		if ( is_multisite() ) {
			$active_plugins = array_merge( $active_plugins, get_site_option( 'active_sitewide_plugins', array() ) );
		}

		return $active_plugins;
	}
}

/**
 * WooCommerce Detection
 */
if ( ! function_exists( 'is_woocommerce_active' ) ) {
	function is_woocommerce_active() {
		$active_plugins = get_active_plugins();

		return in_array( 'woocommerce/woocommerce.php', $active_plugins ) || array_key_exists( 'woocommerce/woocommerce.php', $active_plugins );
	}
}

/**
 * WC Vendors Detection
 */
if ( ! function_exists( 'is_wcvendors_active' ) ) {
	function is_wcvendors_active() {
		$active_plugins = get_active_plugins();

		return in_array( 'wc-vendors/class-wc-vendors.php', $active_plugins ) || array_key_exists( 'wc-vendors/class-wc-vendors.php', $active_plugins );
	}
}

/**
 *    WC Vendors 2.0.0
 */
if ( ! function_exists( 'is_wcvendors_2_0_0' ) ) {
	function is_wcvendors_2_0_0() {
		if ( class_exists( 'WC_Vendors' ) ) {
			return version_compare( WCV_VERSION, '2.0.0', '<' );
		}
	}
}


/**
 * WooCommerce Required Notice
 */
if ( ! function_exists( 'woocommerce_required_notice' ) ) {
	function woocommerce_required_notice() {
		echo '<div class="error"><p><strong>' . __( 'WooCommerce not found. WC Vendors Pro requires a minimum of WooCommerce v3.3.0.', 'wcvendors-pro' ) . '</strong></p></div>';
	}
}

/**
 * WCVendors Required Notice
 */
if ( ! function_exists( 'wcvendors_required_notice' ) ) {
	function wcvendors_required_notice() {
		echo '<div class="error"><p><strong>' . __( 'WC Vendors Marketplace not found. WC Vendors Pro requires a minimum of WC Vendors Marketplace v2.0.0', 'wcvendors-pro' ) . '</strong></p></div>';
	}
}


/**
 * WCVendors 2.0.0 Required Notice
 */
if ( ! function_exists( 'wcvendors_2_required_notice' ) ) {
	function wcvendors_2_required_notice() {
		echo '<div class="error"><p>' . __( '<b>WC Vendors Pro requires a minimum of WC Vendors Marketplace v2.0.0', 'wcvendors-pro' ) . '</p></div>';
	}
}


/*
*	Check to see if the current page is a pro dashboard page
*/
if ( ! function_exists( 'wcv_is_dashboard_page' ) ) {
	function wcv_is_dashboard_page( $current_page = 0 ) {

		if ( ! $current_page ) {
			$current_page = get_the_ID();
		}
		if ( ! $current_page ) {
			return false;
		}

		$dashboard_page_ids = (array) get_option( 'wcvendors_dashboard_page_id', array() );
		if ( empty( $dashboard_page_ids ) ) {
			return false;
		}

		return in_array( $current_page, $dashboard_page_ids );
	}
}


if ( ! function_exists( 'wcv_percentage_to_price' ) ) {
	/**
	 * Converts a percentage to a formatted price
	 *
	 * @param string $percentage The percentage value
	 * @param float  $price      The actual price
	 *
	 * @since 1.5.6
	 */
	function wcv_percentage_to_price( $percentage, $price ) {

		if ( stripos( $percentage, '%' ) > 0 ) {
			$percentage_to_price = wc_price( (float) $price * ( (float) $percentage / 100 ) );
		} else {
			$percentage_to_price = wc_price( $percentage );
		}

		return $percentage_to_price;
	}
}

if ( ! function_exists( 'wcv_get_vendor_id' ) ) {
	/**
	 * Get the vendor id
	 *
	 * @return    int $vendor_id
	 * @since      1.5.9
	 * @version    1.5.9
	 */
	function wcv_get_vendor_id() {
		global $post;

		if ( is_user_logged_in() && current_user_can( 'vendor' ) ) {
			return get_current_user_id();
		}

		if ( WCV_Vendors::is_vendor_page() ) {
			$vendor_shop = urldecode( get_query_var( 'vendor_shop' ) );
			$vendor_id   = WCV_Vendors::get_vendor_id( $vendor_shop );
		} elseif ( is_singular( 'product' ) && WCV_Vendors::is_vendor_product_page( $post->post_author ) ) {
			$vendor_id = $post->post_author;
		} else {
			if ( isset( $_GET['wcv_vendor_id'] ) ) {
				$vendor_id = $_GET['wcv_vendor_id'];
			}
		}

		return false;
	}
}

if ( ! function_exists( 'get_time_interval_options' ) ) {
	/**
	 * Make an array of 30 minute time intervals
	 *
	 * @return  array
	 * @since   1.5.9
	 * @version 1.5.9
	 */
	function get_time_interval_options() {
		$start = new \DateTime( '00:00' );
		$times = 24 * 2;

		for ( $i = 0; $i < $times - 1; $i ++ ) {
			$result[] = $start->add( new \DateInterval( 'PT30M' ) )->format( 'H:i A' );
		}

		return $result;
	}
}

if ( ! function_exists( 'wcv_options_html' ) ) {
	/**
	 * Generate options for a select input given an array of options
	 *
	 * @param    array $options
	 *
	 * @return  string
	 * @since   1.5.9
	 * @version 1.5.9
	 */
	function wcv_options_html( $options ) {
		$options_html = '';
		foreach ( $options as $option ) {
			if ( is_array( $option ) ) {
				foreach ( $option as $key => $value ) {
					$options_html .= '<option value="' . $key . '">' . $value . '</option>' . "\n";
				}
			} else {
				$options_html .= '<option value="' . $option . '">' . $option . '</option>' . "\n";
			}
		}

		return $options_html;
	}
}

if ( ! function_exists( 'wcv_get_default_opening_hours' ) ) {
	/**
	 * Get default opening hours
	 *
	 * @return  array
	 * @since   1.5.9
	 * @version 1.5.9
	 */
	function wcv_get_default_opening_hours() {
		return apply_filters(
			'wcv_default_opeing_hours',
			array(
				array(
					'status' => 1,
					'day'    => 'weekdays',
					'open'   => 'open',
					'close'  => 'open',
				),
			)
		);
	}
}

if ( ! function_exists( 'wcv_strip_html' ) ) {
	/**
	 * Strip html tags and remove extra spaces from the resulting string
	 *
	 * @param    string $string
	 *
	 * @return    string
	 * @since      1.5.9
	 * @version    1.5.9
	 */
	function wcv_strip_html( $string ) {

		$string = strip_tags( $string );
		$string = preg_replace( '/\s+/', ' ', $string );

		return trim( $string );
	}
}


if ( ! function_exists( 'wcv_is_vendor_dashboard' ) ){
	/**
	 * Check if this is the vendor dashboard page
	 */
	function wcv_is_vendor_dashboard(){

		$free_page_id   		= get_option( 'wcvendors_vendor_dashboard_page_id' );
		$dashboard_page_ids   	= (array) get_option( 'wcvendors_dashboard_page_id', array() );

		if ( ! $free_page_id || ! $dashboard_page_ids ) {
	        return false;
	    }

	    if ( $free_page_id == get_the_ID() || in_array( get_the_ID(), $dashboard_page_ids ) ) {
	        return true;
	    }

    	return false;

	}
}

/**
 * Get header type option then return the corresponding template file name.
 *
 * @return string
 */
function wcv_get_store_header_template() {
	$type = get_option( 'wcvendors_vendor_store_header_type', 'pro' );

	if ( 'pro-modern' === $type ) {
		return 'store-header-modern.php';
	}

	return 'store-header.php';
}